@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2010 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -111,11 +111,7 @@ public class PublicationParser {
             PublicationTarget target = discovery.getTarget(object.getString(TARGET));
             publication.setTarget(target);
             
-            if(target != null && object.has(target.getId())) {
-                publication.setConfiguration(formParser.parse(object.getJSONObject(target.getId()), target.getFormDescription()));
-            } else {
-                publication.setConfiguration(new HashMap<String, Object>());
-            }
+            publication.setConfiguration(formParser.parse(object.getJSONObject(target.getId()), target.getFormDescription()));
         }
         return publication;
     }
